@@ -436,6 +436,11 @@
                 });
             });
 
+            // work around default filter
+            $element.filterable("option", "filterCallback", function() {
+                return false;
+            });
+
             this._pushState(null, $(options.title).text(), null);
             this.go(0);
         },
@@ -523,6 +528,8 @@
                 $(options.back).toggle(index > 0);
                 $(options.forward).toggle(index < history.length - 1);
                 $(options.title).text(history[index].title || "");
+                // data-input not in options?
+                $(widget.element.jqmData("input")).val("");
                 this._currentHistoryIndex = index;
             }
         },
