@@ -9,7 +9,8 @@ class ExtensionTest(unittest.TestCase):
 
     def test_get_default_config(self):
         ext = Extension()
-        config = ext.get_default_config()
+        # FIXME: config.read() returns byte string?
+        config = ext.get_default_config().decode('utf-8')
         self.assertIn('[http-kuechenradio]', config)
         self.assertIn('enabled = true', config)
 
